/**
 * @file MoistureSensor.cpp
 * @author Samuel Helbling (samuel.helbling@ost.ch)
 * @brief 
 * @version 0.2
 * @date 2022-03-31
 * 
 * @copyright Copyright (c) 2022
 * 
 */

#include "Arduino.h"
#include "MoistureSensor.h"
#include <stdlib.h>

/**
 * @brief Construct a new Moisture Sensor:: Moisture Sensor object
 * 
 * @param address I2C address of display
 */
MoistureSensor::MoistureSensor(uint8_t address) : address{address}{
};

/**
 * @brief Must be called during setup. Initializes display
 * 
 */
void MoistureSensor::begin(){
    display.init();
    display.clear();
}

/**
 * @brief Call for watering flowerpot
 * 
 * @return returns current moisture as int
 */
int MoistureSensor::watering(){
    if (soilMoisture<100){
        soilMoisture++;
        writeToDisplay();
    }
    return soilMoisture;
}

/**
 * @brief Call to update and get moisture
 * 
 * @return returns current moisture as int 
 */
int MoistureSensor::getSoilMoisture(){
    soilMoisture = soilMoisture - random(3);
    if(soilMoisture<0){
        soilMoisture=0;
    }
    writeToDisplay();
    return soilMoisture;
}

// Private functions

void MoistureSensor::writeToDisplay(){
    display.clear();
    display.setCursor(0,0);
    display.print(soilMoisture);
    display.setCursor(4,0);
    display.print("%");
    delay(50);
}